# AuthenticationDocument

An authentication document is used to provide proof of identity without requiring an interactive, user-facing login.
## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**metadata** | [**MetadataWithId**](MetadataWithId.md) |  | [optional] 
**spec** | [**AuthenticationDocumentSpec**](AuthenticationDocumentSpec.md) |  | 
**status** | [**AuthenticationDocumentStatus**](AuthenticationDocumentStatus.md) |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


